#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="latest"
}

do_install_detail() {
  local config=`uci get webtop.@webtop[0].config_path 2>/dev/null`
  local port=`uci get webtop.@webtop[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get webtop.@webtop[0].image_name 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=3000
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=latest

  
  # Create Docker Compose file with custom variables
 rm -R /opt/docker2/compose/webtop
 mkdir /opt/docker2/compose/webtop
  # Create Docker Compose file with custom variables
touch /opt/docker2/compose/webtop/docker-compose.yml
cat > /opt/docker2/compose/webtop/docker-compose.yml <<EOF
version: "2.1"
services:
  webtop:
    image: lscr.io/linuxserver/webtop:${IMAGE_NAME}
    container_name: webtop
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=Etc/UTC
    volumes:
      - ${config}:/config
    ports:
      - ${port}:3000
    shm_size: "1gb" #optional
    restart: unless-stopped
    labels:
      plugsy.name: "WebTop"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/icomoon/Windows"
      plugsy.link: "http://${LAN_IP}:${port}"
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install webtop"
  echo "      upgrade                Upgrade webtop"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart webtop"
  echo "      status                 webtop status"
  echo "      port                   webtop port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f webtop
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} webtop
  ;;
  "status")
    docker ps --all -f 'name=webtop' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=webtop' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
